@@ -33,12 +33,10 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include <gtk/gtkdialog.h>
 #include <gtk/gtkentry.h>
 #include <gtk/gtklabel.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtksignal.h>
 #include <gtk/gtktogglebutton.h>
-#include <libgnomeui/gnome-dialog.h>
 #include <libgnomeui/gnome-propertybox.h>
 #include <glade/glade.h>
 #include "gal/util/e-util.h"
@@ -50,9 +48,7 @@
 #include <e-table-memory-store.h>
 
 
-#define PARENT_TYPE (gtk_object_get_type())
-
-static GtkObjectClass *config_parent_class;
+static GObjectClass *config_parent_class;
 
 enum {
 	CHANGED,
@@ -60,8 +56,8 @@ enum {
 };
 
 enum {
-	ARG_0,
-	ARG_STATE
+	PROP_0,
+	PROP_STATE,
 };
 
 static guint e_table_config_signals [LAST_SIGNAL] = { 0, };
@@ -71,14 +67,16 @@ config_finalize (GObject *object)
 {
 	ETableConfig *config = E_TABLE_CONFIG (object);
 
-	gtk_object_destroy (GTK_OBJECT (config->state));
+	if (config->state)
+		g_object_unref (config->state);
+	config->state = NULL;
 
 	if (config->source_state)
-		gtk_object_unref (GTK_OBJECT (config->source_state));
+		g_object_unref (config->source_state);
 	config->source_state = NULL;
 
 	if (config->source_spec)
-		gtk_object_unref (GTK_OBJECT (config->source_spec));
+		g_object_unref (config->source_spec);
 	config->source_spec = NULL;
 
 	g_free (config->header);
@@ -90,62 +88,73 @@ config_finalize (GObject *object)
 	g_free (config->domain);
 	config->domain = NULL;
 
-	G_OBJECT_CLASS (config_parent_class)->finalize (object);
+	config_parent_class->finalize (object);
 }
 
 static void
-config_get_arg (GtkObject *o, GtkArg *arg, guint arg_id)
+e_table_config_changed (ETableConfig *config, ETableState *state)
 {
-	ETableConfig *config = E_TABLE_CONFIG (o);
+	g_return_if_fail (E_IS_TABLE_CONFIG (config));
 
-	switch (arg_id){
-	case ARG_STATE:
-		GTK_VALUE_OBJECT (*arg) = (GtkObject *) config->state;
+	g_signal_emit(G_OBJECT(config), e_table_config_signals [CHANGED], 0, state);
+}
+
+static void
+config_dialog_changed (ETableConfig *config)
+{
+	/* enable the apply/ok buttons */
+	gtk_dialog_set_response_sensitive (GTK_DIALOG (config->dialog_toplevel),
+					   GTK_RESPONSE_APPLY, TRUE);
+	gtk_dialog_set_response_sensitive (GTK_DIALOG (config->dialog_toplevel),
+					   GTK_RESPONSE_OK, TRUE);
+}
+
+static void
+config_get_property (GObject *object,
+		     guint prop_id,
+		     GValue *value,
+		     GParamSpec *pspec)
+{
+	ETableConfig *config = E_TABLE_CONFIG (object);
+
+	switch (prop_id) {
+	case PROP_STATE:
+		g_value_set_object (value, config->state);
 		break;
-
 	default:
 		break;
 	}
 }
 
 static void
-e_table_config_changed (ETableConfig *config, ETableState *state)
-{
-	g_return_if_fail (config != NULL);
-	g_return_if_fail (E_IS_TABLE_CONFIG (config));
-
-	
-	gtk_signal_emit(GTK_OBJECT(config),
-			e_table_config_signals [CHANGED],
-			state);
-}
-
-static void
-config_class_init (GtkObjectClass *object_class)
+config_class_init (GObjectClass *object_class)
 {
 	ETableConfigClass *klass = E_TABLE_CONFIG_CLASS(object_class);
 
-	config_parent_class   = gtk_type_class (PARENT_TYPE);
+	config_parent_class   = g_type_class_peek_parent (klass);
 	
 	klass->changed        = NULL;
 
-	object_class->get_arg = config_get_arg;
-	G_OBJECT_CLASS (object_class)->finalize = config_finalize;
+	object_class->finalize = config_finalize;
+	object_class->get_property = config_get_property;
 
 	e_table_config_signals [CHANGED] =
-		gtk_signal_new ("changed",
-				GTK_RUN_LAST,
-				E_OBJECT_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (ETableConfigClass, changed),
-				gtk_marshal_NONE__NONE,
-				GTK_TYPE_NONE, 0);
+		g_signal_new ("changed",
+			      E_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (ETableConfigClass, changed),
+			      (GSignalAccumulator) NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE, 0);
 
-	E_OBJECT_CLASS_ADD_SIGNALS (object_class, e_table_config_signals, LAST_SIGNAL);
+	g_object_class_install_property (object_class, PROP_STATE,
+					 g_param_spec_object ("state",
+							      _("State"),
+							      /*_( */"XXX blurb" /*)*/,
+							      E_TABLE_STATE_TYPE,
+							      G_PARAM_READABLE));
 
-	gtk_object_add_arg_type ("ETableConfig::state", E_TABLE_STATE_TYPE,
-				 GTK_ARG_READABLE, ARG_STATE);
-
-	glade_gnome_init ();
+	glade_init ();
 }
 
 static ETableColumnSpecification *
@@ -205,11 +214,11 @@ update_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 		/*
 		 * Sorting is set, auto select the text
 		 */
-		gtk_signal_handler_block (
-			GTK_OBJECT (widgets [i].radio_ascending),
+		g_signal_handler_block (
+			widgets [i].radio_ascending,
 			widgets [i].toggled_id);
-		gtk_signal_handler_block (
-			GTK_OBJECT (widgets [i].combo->entry),
+		g_signal_handler_block (
+			widgets [i].combo->entry,
 			widgets [i].changed_id);
 		
 		if (i < count){
@@ -261,13 +270,13 @@ update_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 		}
 
 		/* Set the text */
-		gtk_combo_text_set_text (widgets [i].combo, text);
+		gal_combo_text_set_text (widgets [i].combo, text);
 
-		gtk_signal_handler_unblock (
-			GTK_OBJECT (widgets [i].radio_ascending),
+		g_signal_handler_unblock (
+			widgets [i].radio_ascending,
 			widgets [i].toggled_id);
-		gtk_signal_handler_unblock (
-			GTK_OBJECT (widgets [i].combo->entry),
+		g_signal_handler_unblock (
+			widgets [i].combo->entry,
 			widgets [i].changed_id);
 	}
 }
@@ -346,7 +355,7 @@ config_group_info_update (ETableConfig *config)
 	}
 	if (res->str [0] == 0)
 		g_string_append (res, _("No grouping"));
-	
+
 	gtk_label_set_text (GTK_LABEL (config->group_label), res->str);
 	g_string_free (res, TRUE);
 }
@@ -356,15 +365,24 @@ setup_fields (ETableConfig *config)
 {
 	int i;
 
+	e_table_model_freeze (config->available_model);
+	e_table_model_freeze (config->shown_model);
 	e_table_without_show_all (config->available_model);
 	e_table_subset_variable_clear (config->shown_model);
 
 	if (config->temp_state) {
 		for (i = 0; i < config->temp_state->col_count; i++) {
-			e_table_subset_variable_add (config->shown_model, config->temp_state->columns[i]);
-			e_table_without_hide (config->available_model, (void *) config->temp_state->columns[i]);
+			gint j, idx;
+			for (j = 0, idx = 0; j < config->temp_state->columns[i]; j++)
+				if (!config->source_spec->columns[j]->disabled)
+					idx++;
+
+			e_table_subset_variable_add (config->shown_model, idx);
+			e_table_without_hide (config->available_model, GINT_TO_POINTER(idx));
 		}
 	}
+	e_table_model_thaw (config->available_model);
+	e_table_model_thaw (config->shown_model);
 }
 
 static void
@@ -396,8 +414,8 @@ config_fields_info_update (ETableConfig *config)
 static void
 do_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 {
-	GnomeDialog *dialog;
-	int button, running = 1;
+	GtkDialog *dialog;
+	int response, running = 1;
 
 	config->temp_state = e_table_state_duplicate (config->state);
 
@@ -410,14 +428,16 @@ do_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 		
 
 	if (is_sort)
-		dialog = GNOME_DIALOG (config->dialog_sort);
+		dialog = GTK_DIALOG (config->dialog_sort);
 	else
-		dialog = GNOME_DIALOG (config->dialog_group_by);
+		dialog = GTK_DIALOG (config->dialog_group_by);
 	
+	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (config->dialog_toplevel));
+
 	do {
-		button = gnome_dialog_run (dialog);
-		switch (button){
-		case 0:
+		response = gtk_dialog_run (dialog);
+		switch (response){
+		case 0: /* clear fields */
 			if (is_sort){
 				e_table_sort_info_sorting_truncate (
 					config->temp_state->sort_info, 0);
@@ -426,29 +446,27 @@ do_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 					config->temp_state->sort_info, 0);
 			}
 			update_sort_and_group_config_dialog (config, is_sort);
-			continue;
+			break;
 
-			/* OK */
-		case 1:
-			gtk_object_unref (GTK_OBJECT (config->state));
+		case GTK_RESPONSE_OK:
+			g_object_unref (config->state);
 			config->state = config->temp_state;
 			config->temp_state = 0;
 			running = 0;
-			gnome_property_box_changed (
-				GNOME_PROPERTY_BOX (config->dialog_toplevel));
+			config_dialog_changed (config);
 			break;
 
-			/* CANCEL */
-		case 2:
-			gtk_object_unref (GTK_OBJECT (config->temp_state));
+		case GTK_RESPONSE_DELETE_EVENT:
+		case GTK_RESPONSE_CANCEL:
+			g_object_unref (config->temp_state);
 			config->temp_state = 0;
 			running = 0;
 			break;
 		}
 		
 	} while (running);
-	gnome_dialog_close (GNOME_DIALOG (dialog));
-
+	gtk_widget_hide (GTK_WIDGET (dialog));
+	
 	if (is_sort)
 		config_sort_info_update (config);
 	else
@@ -458,35 +476,40 @@ do_sort_and_group_config_dialog (ETableConfig *config, gboolean is_sort)
 static void
 do_fields_config_dialog (ETableConfig *config)
 {
-	int button, running = 1;
+	int response, running = 1;
+
+	gtk_widget_ensure_style (config->dialog_show_fields);
+	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (config->dialog_show_fields)->vbox), 0);
+	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (config->dialog_show_fields)->action_area), 12);
 
 	config->temp_state = e_table_state_duplicate (config->state);
 
 	setup_fields (config);
 
+	gtk_window_set_transient_for (GTK_WINDOW (config->dialog_show_fields),
+				      GTK_WINDOW (config->dialog_toplevel));
+
 	do {
-		button = gnome_dialog_run (GNOME_DIALOG(config->dialog_show_fields));
-		switch (button){
-			/* OK */
-		case 0:
-			gtk_object_unref (GTK_OBJECT (config->state));
+		response = gtk_dialog_run (GTK_DIALOG(config->dialog_show_fields));
+		switch (response){
+		case GTK_RESPONSE_OK:
+			g_object_unref (config->state);
 			config->state = config->temp_state;
 			config->temp_state = 0;
 			running = 0;
-			gnome_property_box_changed (
-				GNOME_PROPERTY_BOX (config->dialog_toplevel));
+			config_dialog_changed (config);
 			break;
 
-			/* CANCEL */
-		case 1:
-			gtk_object_unref (GTK_OBJECT (config->temp_state));
+		case GTK_RESPONSE_DELETE_EVENT:
+		case GTK_RESPONSE_CANCEL:
+			g_object_unref (config->temp_state);
 			config->temp_state = 0;
 			running = 0;
 			break;
 		}
 		
 	} while (running);
-	gnome_dialog_close (GNOME_DIALOG (config->dialog_show_fields));
+	gtk_widget_hide (GTK_WIDGET (config->dialog_show_fields));
 
 	config_fields_info_update (config);
 }
@@ -494,6 +517,7 @@ do_fields_config_dialog (ETableConfig *config)
 
 ETableMemoryStoreColumnInfo store_columns[] = {
 	E_TABLE_MEMORY_STORE_STRING,
+	E_TABLE_MEMORY_STORE_INTEGER,
 	E_TABLE_MEMORY_STORE_TERMINATOR
 };
 
@@ -506,10 +530,14 @@ create_global_store (ETableConfig *config)
 
 	global_store = e_table_memory_store_new (store_columns);
 	for (i = 0; config->source_spec->columns[i]; i++) {
-		char *text = e_utf8_from_locale_string (dgettext (config->domain,
-								  config->source_spec->columns[i]->title));
 
-		e_table_memory_store_insert_adopt (E_TABLE_MEMORY_STORE (global_store), i, NULL, text);
+		char *text;
+
+		if (config->source_spec->columns[i]->disabled)
+			continue;
+
+		text = g_strdup (dgettext (config->domain, config->source_spec->columns[i]->title));
+		e_table_memory_store_insert_adopt (E_TABLE_MEMORY_STORE (global_store), -1, NULL, text, i);
 	}
 }
 
@@ -567,19 +595,25 @@ config_button_group (GtkWidget *widget, ETableConfig *config)
 }
 
 static void
-dialog_destroyed (GtkObject *dialog, ETableConfig *config)
+dialog_destroyed (gpointer data, GObject *where_object_was)
 {
-	gtk_object_destroy (GTK_OBJECT (config));
+	ETableConfig *config = data;
+	g_object_unref (config);
 }
 
 static void
-dialog_apply (GnomePropertyBox *pbox, gint page_num, ETableConfig *config)
+dialog_response (GtkWidget *dialog, int response_id, ETableConfig *config)
 {
-	if (page_num != -1)
-		return;
+	if (response_id == GTK_RESPONSE_APPLY
+	    || response_id == GTK_RESPONSE_OK) {
+		e_table_config_changed (config, config->state);
+	}
 
-	e_table_config_changed (config, config->state);
-}
+	if (response_id == GTK_RESPONSE_CANCEL
+	    || response_id == GTK_RESPONSE_OK) {
+		gtk_widget_destroy (dialog);
+	}
+}	
 
 /*
  * Invoked by the Glade auto-connect code
@@ -588,7 +622,7 @@ GtkWidget *e_table_proxy_gtk_combo_text_new (void);
 GtkWidget *
 e_table_proxy_gtk_combo_text_new (void)
 {
-	return gtk_combo_text_new (TRUE);
+	return gal_combo_text_new (TRUE);
 }
 
 #if 0
@@ -604,16 +638,27 @@ configure_dialog (GladeXML *gui, const char *widget_name, ETableConfig *config)
 #endif
 
 static void
-connect_button (ETableConfig *config, GladeXML *gui, const char *widget_name, GtkSignalFunc cback)
+connect_button (ETableConfig *config, GladeXML *gui, const char *widget_name, GCallback cback)
 {
 	GtkWidget *button = glade_xml_get_widget (gui, widget_name);
 
 	if (button) {
-		gtk_signal_connect (GTK_OBJECT (button), "clicked",
-				    cback, config);
+		g_signal_connect (G_OBJECT (button), "clicked",
+				  cback, config);
 	}
 }
 
+static gint
+get_source_model_col_index (ETableConfig *config, gint idx)
+{
+	gint visible_index;
+	ETableModel *src_model = E_TABLE_SUBSET (config->available_model)->source;
+
+        visible_index = e_table_subset_view_to_model_row (E_TABLE_SUBSET (config->available_model), idx);
+	
+	return GPOINTER_TO_INT (e_table_model_value_at (src_model, 1, visible_index));
+}
+
 static void
 sort_entry_changed (GtkEntry *entry, ETableConfigSortWidgets *sort)
 {
@@ -670,10 +715,10 @@ configure_sort_dialog (ETableConfig *config, GladeXML *gui)
 		char buffer [80];
 
 		snprintf (buffer, sizeof (buffer), "sort-combo-%d", i + 1);
-		config->sort [i].combo = GTK_COMBO_TEXT (
+		config->sort [i].combo = GAL_COMBO_TEXT (
 			glade_xml_get_widget (gui, buffer));
-
-		gtk_combo_text_add_item (config->sort [i].combo, "", "");
+		gtk_widget_show (GTK_WIDGET (config->sort [i].combo));
+		gal_combo_text_add_item (config->sort [i].combo, "", "");
 
 		snprintf (buffer, sizeof (buffer), "frame-sort-%d", i + 1);
 		config->sort [i].frames = 
@@ -698,7 +743,7 @@ configure_sort_dialog (ETableConfig *config, GladeXML *gui)
 		char *label = l->data;
 
 		for (i = 0; i < 4; i++){
-			gtk_combo_text_add_item (config->sort [i].combo,
+			gal_combo_text_add_item (config->sort [i].combo,
 						 dgettext (config->domain, label), label);
 		}
 	}
@@ -707,14 +752,14 @@ configure_sort_dialog (ETableConfig *config, GladeXML *gui)
 	 * After we have runtime modified things, signal connect
 	 */
 	for (i = 0; i < 4; i++){
-		config->sort [i].changed_id = gtk_signal_connect (
-			GTK_OBJECT (config->sort [i].combo->entry),
-			"changed", GTK_SIGNAL_FUNC (sort_entry_changed),
+		config->sort [i].changed_id = g_signal_connect (
+			config->sort [i].combo->entry,
+			"changed", G_CALLBACK (sort_entry_changed),
 			&config->sort [i]);
 
-		config->sort [i].toggled_id = gtk_signal_connect (
-			GTK_OBJECT (config->sort [i].radio_ascending),
-			"toggled", GTK_SIGNAL_FUNC (sort_ascending_toggled),
+		config->sort [i].toggled_id = g_signal_connect (
+			config->sort [i].radio_ascending,
+			"toggled", G_CALLBACK (sort_ascending_toggled),
 			&config->sort [i]);
 	}
 }
@@ -774,10 +819,11 @@ configure_group_dialog (ETableConfig *config, GladeXML *gui)
 		char buffer [80];
 
 		snprintf (buffer, sizeof (buffer), "group-combo-%d", i + 1);
-		config->group [i].combo = GTK_COMBO_TEXT (
+		config->group [i].combo = GAL_COMBO_TEXT (
 			glade_xml_get_widget (gui, buffer));
+		gtk_widget_show (GTK_WIDGET (config->group [i].combo));
 
-		gtk_combo_text_add_item (config->group [i].combo, "", "");
+		gal_combo_text_add_item (config->group [i].combo, "", "");
 
 		snprintf (buffer, sizeof (buffer), "frame-group-%d", i + 1);
 		config->group [i].frames = 
@@ -809,7 +855,7 @@ configure_group_dialog (ETableConfig *config, GladeXML *gui)
 		char *label = l->data;
 
 		for (i = 0; i < 4; i++){
-			gtk_combo_text_add_item (
+			gal_combo_text_add_item (
 				config->group [i].combo,
 				dgettext (config->domain, label), label);
 		}
@@ -819,14 +865,14 @@ configure_group_dialog (ETableConfig *config, GladeXML *gui)
 	 * After we have runtime modified things, signal connect
 	 */
 	for (i = 0; i < 4; i++){
-		config->group [i].changed_id = gtk_signal_connect (
-			GTK_OBJECT (config->group [i].combo->entry),
-			"changed", GTK_SIGNAL_FUNC (group_entry_changed),
+		config->group [i].changed_id = g_signal_connect (
+			config->group [i].combo->entry,
+			"changed", G_CALLBACK (group_entry_changed),
 			&config->group [i]);
 
-		config->group [i].toggled_id = gtk_signal_connect (
-			GTK_OBJECT (config->group [i].radio_ascending),
-			"toggled", GTK_SIGNAL_FUNC (group_ascending_toggled),
+		config->group [i].toggled_id = g_signal_connect (
+			config->group [i].radio_ascending,
+			"toggled", G_CALLBACK (group_ascending_toggled),
 			&config->group [i]);
 	}
 }
@@ -855,7 +901,7 @@ config_button_add (GtkWidget *widget, ETableConfig *config)
 	config->temp_state->expansions = g_renew (double, config->temp_state->expansions, config->temp_state->col_count + count);
 	i = config->temp_state->col_count;
 	for (column = columns; column; column = column->next) {
-		config->temp_state->columns[i] = e_table_subset_view_to_model_row (E_TABLE_SUBSET (config->available_model), GPOINTER_TO_INT (column->data));
+		config->temp_state->columns[i] = get_source_model_col_index (config, GPOINTER_TO_INT (column->data));
 		config->temp_state->expansions[i] = config->source_spec->columns[config->temp_state->columns[i]]->expansion;
 		i++;
 	}
@@ -991,20 +1037,26 @@ config_button_down (GtkWidget *widget, ETableConfig *config)
 static void
 configure_fields_dialog (ETableConfig *config, GladeXML *gui)
 {
-	config->available = e_table_scrolled_get_table (E_TABLE_SCROLLED (glade_xml_get_widget (gui, "custom-available")));
-	gtk_object_get (GTK_OBJECT (config->available),
-			"model", &config->available_model,
-			NULL);
+	GtkWidget *scrolled;
 
-	config->shown = e_table_scrolled_get_table (E_TABLE_SCROLLED (glade_xml_get_widget (gui, "custom-shown")));
-	gtk_object_get (GTK_OBJECT (config->shown),
-			"model", &config->shown_model,
-			NULL);
+	scrolled = glade_xml_get_widget (gui, "custom-available");
+	config->available = e_table_scrolled_get_table (E_TABLE_SCROLLED (scrolled));
+	g_object_get (config->available,
+		      "model", &config->available_model,
+		      NULL);
+	gtk_widget_show_all (scrolled);
 
-	connect_button (config, gui, "button-add",    GTK_SIGNAL_FUNC (config_button_add));
-	connect_button (config, gui, "button-remove", GTK_SIGNAL_FUNC (config_button_remove));
-	connect_button (config, gui, "button-up",     GTK_SIGNAL_FUNC (config_button_up));
-	connect_button (config, gui, "button-down",   GTK_SIGNAL_FUNC (config_button_down));
+	scrolled = glade_xml_get_widget (gui, "custom-shown");
+	config->shown = e_table_scrolled_get_table (E_TABLE_SCROLLED (scrolled));
+	g_object_get (config->shown,
+		      "model", &config->shown_model,
+		      NULL);
+	gtk_widget_show_all (scrolled);
+
+	connect_button (config, gui, "button-add",    G_CALLBACK (config_button_add));
+	connect_button (config, gui, "button-remove", G_CALLBACK (config_button_remove));
+	connect_button (config, gui, "button-up",     G_CALLBACK (config_button_up));
+	connect_button (config, gui, "button-down",   G_CALLBACK (config_button_down));
 
 	setup_fields (config);
 }
@@ -1022,7 +1074,7 @@ setup_gui (ETableConfig *config)
 		gui = glade_xml_new (ETABLE_GLADEDIR "/e-table-config-no-group.glade", NULL, E_I18N_DOMAIN);
 	}
 
-	gtk_object_unref (GTK_OBJECT (global_store));
+	g_object_unref (global_store);
 	
 	config->dialog_toplevel = glade_xml_get_widget (
 		gui, "e-table-config");
@@ -1030,13 +1082,6 @@ setup_gui (ETableConfig *config)
 	if (config->header)
 		gtk_window_set_title (GTK_WINDOW (config->dialog_toplevel), config->header);
 
-	gtk_widget_hide (GNOME_PROPERTY_BOX(config->dialog_toplevel)->help_button);
-
-	gtk_notebook_set_show_tabs (
-		GTK_NOTEBOOK (GNOME_PROPERTY_BOX (
-			config->dialog_toplevel)->notebook),
-		FALSE);
-	
 	config->dialog_show_fields = glade_xml_get_widget (
 		gui, "dialog-show-fields");
 	config->dialog_group_by =  glade_xml_get_widget (
@@ -1051,23 +1096,21 @@ setup_gui (ETableConfig *config)
 	config->fields_label = glade_xml_get_widget (
 		gui, "label-fields");
 
-	connect_button (config, gui, "button-sort", GTK_SIGNAL_FUNC (config_button_sort));
-	connect_button (config, gui, "button-group", GTK_SIGNAL_FUNC (config_button_group));
-	connect_button (config, gui, "button-fields", GTK_SIGNAL_FUNC (config_button_fields));
+	connect_button (config, gui, "button-sort", G_CALLBACK (config_button_sort));
+	connect_button (config, gui, "button-group", G_CALLBACK (config_button_group));
+	connect_button (config, gui, "button-fields", G_CALLBACK (config_button_fields));
 	
 	configure_sort_dialog (config, gui);
 	configure_group_dialog (config, gui);
 	configure_fields_dialog (config, gui);
-	
-	gtk_signal_connect (
-		GTK_OBJECT (config->dialog_toplevel), "destroy",
-		GTK_SIGNAL_FUNC (dialog_destroyed), config);
 
-	gtk_signal_connect (
-		GTK_OBJECT (config->dialog_toplevel), "apply",
-		GTK_SIGNAL_FUNC (dialog_apply), config);
+	g_object_weak_ref (G_OBJECT (config->dialog_toplevel),
+			   dialog_destroyed, config);
 
-	gtk_object_unref (GTK_OBJECT (gui));
+	g_signal_connect (config->dialog_toplevel, "response",
+			  G_CALLBACK (dialog_response), config);
+
+	g_object_unref (gui);
 }
 
 static void
@@ -1080,7 +1123,8 @@ ETableConfig *
 e_table_config_construct (ETableConfig        *config,
 			  const char          *header,
 			  ETableSpecification *spec,
-			  ETableState         *state)
+			  ETableState         *state,
+			  GtkWindow           *parent_window)
 {
 	ETableColumnSpecification **column;
 
@@ -1093,8 +1137,8 @@ e_table_config_construct (ETableConfig        *config,
 	config->source_state = state;
 	config->header = g_strdup (header);
 
-	gtk_object_ref (GTK_OBJECT (config->source_spec));
-	gtk_object_ref (GTK_OBJECT (config->source_state));
+	g_object_ref (config->source_spec);
+	g_object_ref (config->source_state);
 
 	config->state = e_table_state_duplicate (state);
 
@@ -1112,6 +1156,17 @@ e_table_config_construct (ETableConfig        *config,
 
 	setup_gui (config);
 
+	if (parent_window) {
+		gtk_window_set_transient_for (GTK_WINDOW (config->dialog_toplevel),
+					      parent_window);
+		/*
+		  center on parent doesn't seem to work for me, so let use GTK_WIN_POS_CENTER_ALWAYS - that is
+		  what glade used before as well, so it's not worse then it was
+		  gtk_window_set_position (GTK_WINDOW (config->dialog_toplevel), GTK_WIN_POS_CENTER_ON_PARENT);
+		*/
+		gtk_window_set_position (GTK_WINDOW (config->dialog_toplevel), GTK_WIN_POS_CENTER_ALWAYS);
+	}
+
 	config_sort_info_update   (config);
 	config_group_info_update  (config);
 	config_fields_info_update (config);
@@ -1132,16 +1187,24 @@ e_table_config_construct (ETableConfig        *config,
 ETableConfig *
 e_table_config_new (const char          *header,
 		    ETableSpecification *spec,
-		    ETableState         *state)
+		    ETableState         *state,
+		    GtkWindow           *parent_window)
 {
-	ETableConfig *config = gtk_type_new (E_TABLE_CONFIG_TYPE);
+	ETableConfig *config = g_object_new (E_TABLE_CONFIG_TYPE, NULL);
 
-	if (e_table_config_construct (config, header, spec, state) == NULL){
-		gtk_object_destroy (GTK_OBJECT (config));
+	if (e_table_config_construct (config, header, spec, state, parent_window) == NULL){
+		g_object_unref (config);
 		return NULL;
 	}
 
+	gtk_widget_ensure_style (config->dialog_toplevel);
+	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (config->dialog_toplevel)->vbox), 0);
+	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (config->dialog_toplevel)->action_area), 12);
+
+	gtk_dialog_set_response_sensitive (GTK_DIALOG (config->dialog_toplevel),
+					   GTK_RESPONSE_APPLY, FALSE);
 	gtk_widget_show (config->dialog_toplevel);
+
 	return E_TABLE_CONFIG (config);
 }
 
@@ -1157,4 +1220,4 @@ e_table_config_raise (ETableConfig *config)
 	gdk_window_raise (GTK_WIDGET (config->dialog_toplevel)->window);
 }
 
-E_MAKE_TYPE(e_table_config, "ETableConfig", ETableConfig, config_class_init, config_init, PARENT_TYPE)
+E_MAKE_TYPE(e_table_config, "ETableConfig", ETableConfig, config_class_init, config_init, G_TYPE_OBJECT)
