@@ -24,16 +24,15 @@
 #ifndef _E_CATEGORIES_MASTER_LIST_DIALOG_H_
 #define _E_CATEGORIES_MASTER_LIST_DIALOG_H_
 
-#include <libgnome/gnome-defs.h>
 #include <gal/widgets/e-categories-master-list.h>
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 #define E_CATEGORIES_MASTER_LIST_DIALOG_TYPE        (e_categories_master_list_dialog_get_type ())
-#define E_CATEGORIES_MASTER_LIST_DIALOG(o)          (GTK_CHECK_CAST ((o), E_CATEGORIES_MASTER_LIST_DIALOG_TYPE, ECategoriesMasterListDialog))
-#define E_CATEGORIES_MASTER_LIST_DIALOG_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), E_CATEGORIES_MASTER_LIST_DIALOG_TYPE, ECategoriesMasterListDialogClass))
-#define E_IS_CATEGORIES_MASTER_LIST_DIALOG(o)       (GTK_CHECK_TYPE ((o), E_CATEGORIES_MASTER_LIST_DIALOG_TYPE))
-#define E_IS_CATEGORIES_MASTER_LIST_DIALOG_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), E_CATEGORIES_MASTER_LIST_DIALOG_TYPE))
+#define E_CATEGORIES_MASTER_LIST_DIALOG(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), E_CATEGORIES_MASTER_LIST_DIALOG_TYPE, ECategoriesMasterListDialog))
+#define E_CATEGORIES_MASTER_LIST_DIALOG_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), E_CATEGORIES_MASTER_LIST_DIALOG_TYPE, ECategoriesMasterListDialogClass))
+#define E_IS_CATEGORIES_MASTER_LIST_DIALOG(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), E_CATEGORIES_MASTER_LIST_DIALOG_TYPE))
+#define E_IS_CATEGORIES_MASTER_LIST_DIALOG_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), E_CATEGORIES_MASTER_LIST_DIALOG_TYPE))
 
 typedef struct ECategoriesMasterListDialogPriv ECategoriesMasterListDialogPriv;
 
@@ -53,6 +52,6 @@ ECategoriesMasterListDialog *e_categories_master_list_dialog_construct  (ECatego
 									 ECategoriesMasterList       *ecml);
 void                         e_categories_master_list_dialog_raise      (ECategoriesMasterListDialog *ecmld);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif /* _E_CATEGORIES_MASTER_LIST_DIALOG_H */
